from xaal.schemas import devices
from xaal.lib import helpers, tools
import sys


def main(engine):
    addr = None
    if len(sys.argv) > 1:
        addr = tools.get_uuid(sys.argv[-1])
        if not addr:
            print('Wrong address')
            sys.exit(1)

    dev = devices.lamp_toggle(addr)
    dev.vendor_id = 'RAMBo Team'
    dev.product_id = 'lamp_minimal'
    dev.info = 'Dummy Mini Lamp'
    dev.attributes['light'] = False

    # methods
    def on():
        dev.attributes['light'] = True

    def off():
        dev.attributes['light'] = False

    def toggle():
        dev.attributes['light'] = not dev.attributes['light']

    dev.methods['turn_on'] = on
    dev.methods['turn_off'] = off
    dev.methods['toggle'] = toggle
    dev.dump()

    engine.add_device(dev)
    return True


if __name__ == '__main__':
    helpers.run_async_package('lamp_minimal', main)



import asyncio
import functools
import random
import sys

from xaal.lib import AsyncEngine, tools
from xaal.schemas import devices


def usage():
    print("Usage:")
    print("  %s target_address" % sys.argv[0])


def main():
    target = tools.get_uuid(sys.argv[-1])
    if not target:
        usage()
        return

    dev = devices.hmi()
    dev.vendor_id = "RAMBo"
    dev.product_id = "Async Auto Switcher"
    dev.info = 'Switcher for %s' % target
    dev.dump()

    eng = AsyncEngine()
    eng.add_device(dev)

    async def run():
        while 1:
            print(' => turn_on')
            eng.send_request(dev, [target,], 'turn_on')
            await asyncio.sleep(5)

            print(' => turn_off')
            eng.send_request(dev, [target,], 'turn_off')
            await asyncio.sleep(5)

            brightness = random.randint(0, 100)
            print(' => set_brightness %i' % brightness)
            eng.send_request(dev , [target,], 'set_brightness', {'brightness': brightness})
            await asyncio.sleep(5)

    eng.on_start(run)
    eng.on_stop(functools.partial(print, "Bye Bye"))
    eng.run()


if __name__ == '__main__':
    try:
        main()
    except KeyboardInterrupt:
        print("Bye ..")




import time,random,sys
from xaal.lib import Engine,Device,tools
from xaal.schemas import devices

eng = None

def usage():
    print("Usage:")
    print("  %s target_address" % sys.argv[0])

def wait():
    # the plain old engine has to be looped to process the requests
    t0 = time.time()
    while time.time() < (t0+3):
        eng.loop()

def main():
    global eng
    target = tools.get_uuid(sys.argv[-1])
    if not target:
        usage()
        return

    dev = devices.hmi()
    dev.vendor_id = "RAMBo"
    dev.product_id = "Fake Auto Switcher"
    dev.info = 'Switcher for %s' % target
    dev.dump()

    eng = Engine()
    eng.add_device(dev)

    while 1:
        eng.send_request(dev,[target,],'turn_on')
        print(' => turn_on')
        wait()

        brightness = random.randint(0,100)
        eng.send_request(dev,[target,],'set_brightness',{'brightness':brightness})
        print(' => set_brightness %s' % brightness)
        wait()

        eng.send_request(dev,[target,],'turn_off')
        print(' => turn_off')
        wait()

if __name__ == '__main__':
    try:
        main()
    except KeyboardInterrupt:
        print("Bye ..")



from xaal.lib import Device,Engine,tools
import sys

def main(addr):
    if addr is None:
        addr = tools.get_random_uuid()
    dev = Device("lamp.dimmer",addr)
    dev.product_id = 'Dummy Dimming Lamp'
    dev.url = 'http://www.acme.org'
    dev.info = 'Dummy Lamp7'

    # attributes
    light = dev.new_attribute('light',False)
    brightness = dev.new_attribute('brightness',50)
        
    # methods 
    def on():
        light.value = True
        print("%s ON" % dev)
    
    def off():
        light.value = False
        print("%s OFF" %dev)
    
    def dim(_brightness,_smooth=None):
        # this device doesn't support _smooth parameter
        val = int(_brightness)
        if (val <= 100) and (val >=0):
            brightness.value = val
            print("%s Dimming to %d" % (dev,val))

    dev.add_method('turn_on',on)
    dev.add_method('turn_off',off)
    dev.add_method('set_brightness',dim)
    # this is a simple dimmer w/ no white color settings.
    dev.unsupported_methods = ['set_color_temperature']
    dev.unsupported_attributes = ['color_temperature']
    dev.dump()

    eng = Engine()
    eng.add_device(dev)
    eng.run()

if __name__ =='__main__':
    try:
        addr = None
        if len(sys.argv) > 1:
            addr = tools.get_uuid(sys.argv[-1])
            if not addr:
                print("Wrong address")
        main(addr)
    except KeyboardInterrupt:
        pass




from xaal.lib import Device,Engine,tools


import select
import sys
import tty
import termios
import logging


logger = logging.getLogger("temperature.py")


def keyboard_read():
    if select.select([sys.stdin], [], [], 0) == ([sys.stdin], [], []):
        data = sys.stdin.read(1) 
        return data
    
def display_value(value):
    sys.stdout.write('\r Temp : %0.1f' % value)
    sys.stdout.flush()

            
def main(addr):
    if addr == None:
        addr = tools.get_random_uuid()
    dev = Device("thermometer.basic",addr)
    dev.product_id = 'Fake Thermometer'
    dev.url = 'http://www.acme.org'
        
    # attributes
    temp = dev.new_attribute('temperature')
    temp.value = 20.0

    print("Press +/- to change the temperature, q to quit")
    display_value(temp.value)
    
    def run():
        ch = keyboard_read()
        if ch:
            if ch == '+': temp.value = temp.value + 0.1
            if ch == '-': temp.value = temp.value - 0.1
            if ch == 'q' : sys.exit(0)
            display_value(temp.value)

    eng = Engine()
    eng.add_device(dev)
    eng.add_timer(run,0)
    eng.run()

if __name__ == '__main__':
    # drop blocking tty 
    old_settings = termios.tcgetattr(sys.stdin)
    tty.setcbreak(sys.stdin.fileno())
    try:
        addr = None
        if len(sys.argv) > 1:
            addr = tools.str_to_uuid(sys.argv[-1])
            if not addr:
                print("Wrong address")
        main(addr)
    except KeyboardInterrupt:
        pass
    termios.tcsetattr(sys.stdin, termios.TCSADRAIN, old_settings)



txt = """================= xAAL dummy devices =================

This package contains some fake lamps, power_relay, and bots:
    - lamp:         a simple lamp implementation
    - lamp_minimal: a simple lamp using schema devices
    - power_relay:  a power relay 
    - temperature:  a fake temperature sensor
    - autobot:      a bot than send turn_on/off and  set_brightness
    - asyncbot:     same as autobot with asyncio
    

To run a module simply call: python -m xaal.dummy.module 
Example: python -m xaal.dummy.lamp 8e1495cc-b98b-11eb-8432-d6bd5fe18736

All modules accept their address (uuid) as argument. Autobot uuid is the
lamp's address to switch.
"""

print(txt)



from xaal.lib import Device,Engine,tools
import sys
import logging

logger = logging.getLogger("lamp.py")

def main(addr):
    if addr == None:
        addr = tools.get_random_uuid()
    dev = Device("powerrelay.basic",addr)
    dev.product_id = 'Dummy Power Relay'
    dev.url = 'http://www.acme.org'
        
    # attributes
    power = dev.new_attribute('power')

    dev.dump()
    
    # methods 
    def on():
        power.value = True
        print("%s ON" % dev)
    
    def off():
        power.value = False
        print("%s OFF" %dev)
    
    dev.add_method('turn_on',on)
    dev.add_method('turn_off',off)

    eng = Engine()
    eng.add_device(dev)
    eng.run()


if __name__ =='__main__':
    try:
        addr = None
        if len(sys.argv) > 1:
            addr = tools.get_uuid(sys.argv[-1])
        main(addr)
    except KeyboardInterrupt:
        pass
